# Supported Sources & Destinations
ingestr supports the following sources and destinations:

| Database             | Source | Destination |
|----------------------|--------|-------------|
| Postgres             | ✅      | ✅         |
| BigQuery             | ✅      | ✅         |
| Snowflake            | ✅      | ✅         |
| Redshift             | ✅      | ✅         |
| Databricks           | ✅      | ✅         |
| DuckDB               | ✅      | ✅         |
| Microsoft SQL Server | ✅      | ✅         |
| SQLite               | ✅      | ❌         |
| MySQL                | ✅      | ❌         |

More to come soon!
